@@ -1,16 +1,19 @@
-from Corellia.RedisQueue import Client
-from Corellia.RedisStore import KVStore
+from gevent import monkey; monkey.patch_all()
+from Corellia.client import Client
+from Corellia.kvstore import KVStore
 from ..config import config
 from uuid import uuid1
 import Husky
 
+client = Client(config.host, "Briareus", pickler=Husky, serialize=True, interval=0.1)
+
 
 class Cloud(object):
     def __init__(self, f):
         self.f = f
 
     def __call__(self, *args):
-        return Client(config.host, config.port, config.queue_name).eval(self.f, args)
+        return client.eval(self.f, args)
 
     def __getstate__(self):
         return Husky.dumps(self.f)
@@ -24,7 +27,7 @@ class CachedData(object):
 
     def __init__(self, var):
         self.value = var
-        self.id = self.put(self.value)
+        self.put(self.value)
 
     def __getstate__(self):
         return self.id
@@ -37,10 +40,11 @@ class CachedData(object):
             self.__dict__["value"] = self.get(self.id)
             return self.__dict__["value"]
         else:
-            return None
+            return getattr(self.value, name)
 
     def put(self, value):
-        return KVStore(self.name, config.host, config.port).put(uuid1().hex, value)
+        self.id = uuid1().hex
+        KVStore(config.host, self.name).set(self.id, value)
 
     def get(self, key):
         return KVStore(self.name, config.host, config.port).get(key)
