@@ -19,6 +19,8 @@ class Runtime(object):
         return f(*map(self.getvalue, args))
 
 def run():
-    from Corellia.RedisQueue import Worker
+    from gevent import monkey; monkey.patch_all()
+    from Corellia.worker import WorkerPool
+    import Husky
     from ..config import config
-    Worker(config.host, config.port, config.queue_name).run(Runtime)
\ No newline at end of file
+    WorkerPool(config.host, "Briareus", pickler=Husky, serialize=True, interval=0.1, mass=False, num=5).run(Runtime)
\ No newline at end of file
