@@ -19,6 +19,6 @@ def setup(only_gen_source=False):
                         "_cloud": CloudUtils.Cloud,
                         "_cached": CloudUtils.CachedData,
                         "_async": AsyncCallable})
-    code = compile(tree, '<string>', 'exec')
-    eval(code, new_gloabls)
+    code = compile(tree, 'path', 'exec')
+    exec code in new_gloabls
     exit(0)
\ No newline at end of file
